@@ -155,8 +155,7 @@ class MainWindow():
             self.checks.append(APTForeignCheck(callback=self.process_check_result))
             self.checks.append(APTOrphanCheck(pre_upgrade_orphans, self.process_check_result))
         info = ShowInfoCheck(_("Phase 2: Simulation and download"), callback=self.process_check_result)
-        info.message = _("Your package repositories will now point towards the new release.")
-        info.message = _("A few more tests will be run and package updates will be downloaded.")
+        info.message = "%s\n%s" % (_("Your package repositories will now point towards the new release."), _("A few more tests will be run and package updates will be downloaded."))
         self.checks.append(info)
         self.checks.append(UpdateReposCheck(callback=self.process_check_result))
         self.checks.append(APTCacheCheck(self.window, callback=self.process_check_result))
